;;; -*- Mode:Lisp; Syntax:Common-Lisp; Package: FUG5 -*-
;;; -----------------------------------------------------------------------
;;; File:         gsimple.l
;;; Description:  A simple grammar in FUF (tutorial)
;;; Author:       Michael Elhadad
;;; Created:      31 Mar 1996
;;; Modified:     
;;; Package:      FUG5
;;; -----------------------------------------------------------------------

(in-package "FUG5")

(def-grammar gsimple ()
  (setq gsimple
    '((alt GSIMPLE ( 
		    ;; a grammar always has the same form: an alternative
		    ;; with one branch for each constituent category.

		    ;; First branch of the alternative
		    ;; Describe the category clause.
		    ((cat clause)
		     (agent    ((cat np)))
		     (affected ((cat np)))
		     (action   ((cat verb-group)
				(number {agent number})))
		     (cset (action agent affected))
		     (pattern  (agent action affected)))

		    ;; Second branch: NP
		    ((cat np)
		     (head ((cat noun) (lex {^ ^ lex})))
		     (number  ((alt np-number (singular plural))))
		     (alt (  ;; Proper names don't need an article
			     ((proper yes)
			      (pattern (head)))

			     ;; Common names do
			     ((proper no)
			      (pattern (det head))
			      (det ((cat article) (lex "the")))))))

		    ;; Third branch: Verb
		    ((cat verb-group)
		     (pattern (v))
		     (aux none)
		     (v ((cat verb) (lex {^ ^ lex}))))

		    ((cat article)))))))


(def-test i1
  "The system advises John."
  ((cat clause)
   (tense present)
   (action   ((lex "advise")))
   (agent    ((lex "system") (proper no)))
   (affected ((lex "John")))))

(def-test i2
  "<fail>"
  ((cat clause) 
   (agent   ((lex "John") (number singular)))
   (action  ((lex "advise") (number plural)))
   (goal    ((lex "Mary")))))


(gsimple)
(test :item 'i1)
